# World Athletics API

[![PyPI version](https://badge.fury.io/py/worldathletics.svg)](https://badge.fury.io/py/worldathletics)

This is an auto-generated Python wrapper for World Athletics' hidden GraphQL API.

`pip install worldathletics`
